==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GetVirtualServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getVirtualService.
 * @property meshName Name of the service mesh in which the virtual service exists.
 * @property meshOwner AWS account ID of the service mesh's owner.
 * @property name Name of the virtual service.
 * @property tags Map of tags.
 */
public data class GetVirtualServicePlainArgs(
    public val meshName: String,
    public val meshOwner: String? = null,
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs =
        com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs.builder()
            .meshName(meshName.let({ args0 -> args0 }))
            .meshOwner(meshOwner?.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetVirtualServicePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualServicePlainArgsBuilder internal constructor() {
    private var meshName: String? = null

    private var meshOwner: String? = null

    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the service mesh in which the virtual service exists.
     */
    @JvmName("tcphfkgdlhwrqiqi")
    public suspend fun meshName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.meshName = mapped
    }

    /**
     * @param value AWS account ID of the service mesh's owner.
     */
    @JvmName("dcteqiomwjwcxjrd")
    public suspend fun meshOwner(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.meshOwner = mapped
    }

    /**
     * @param value Name of the virtual service.
     */
    @JvmName("oiffafmatnxokqfv")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags.
     */
    @JvmName("ldjiwhogfjpgtoob")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags.
     */
    @JvmName("jppdgyvsolrkpdlw")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetVirtualServicePlainArgs = GetVirtualServicePlainArgs(
        meshName = meshName ?: throw PulumiNullFieldException("meshName"),
        meshOwner = meshOwner,
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GetVirtualServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getVirtualService.
 * @property meshName Name of the service mesh in which the virtual service exists.
 * @property meshOwner AWS account ID of the service mesh's owner.
 * @property name Name of the virtual service.
 * @property tags Map of tags.
 */
public data class GetVirtualServicePlainArgs(
    public val meshName: String,
    public val meshOwner: String? = null,
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs =
        com.pulumi.aws.appmesh.inputs.GetVirtualServicePlainArgs.builder()
            .meshName(meshName.let({ args0 -> args0 }))
            .meshOwner(meshOwner?.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetVirtualServicePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualServicePlainArgsBuilder internal constructor() {
    private var meshName: String? = null

    private var meshOwner: String? = null

    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the service mesh in which the virtual service exists.
     */
    @JvmName("kcmdjkialfttxvvb")
    public suspend fun meshName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.meshName = mapped
    }

    /**
     * @param value AWS account ID of the service mesh's owner.
     */
    @JvmName("cqytrbnpofkwtdry")
    public suspend fun meshOwner(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.meshOwner = mapped
    }

    /**
     * @param value Name of the virtual service.
     */
    @JvmName("thkgyexiesdveawe")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags.
     */
    @JvmName("rekifxvdtnhyofws")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags.
     */
    @JvmName("blrxvrluaroiwhke")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetVirtualServicePlainArgs = GetVirtualServicePlainArgs(
        meshName = meshName ?: throw PulumiNullFieldException("meshName"),
        meshOwner = meshOwner,
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
